@@ -9,8 +9,6 @@ from .fields.signature import Signature
 
 
 class FormFinisher:
-    weasy_form = None
-
     def __init__(self, inject_empty_cryptographic_signature: bool = False):
         self.inject_empty_cryptographic_signature = inject_empty_cryptographic_signature
 
@@ -26,7 +24,6 @@ class FormFinisher:
                     matrix = Matrix(scale, 0, 0, -scale, 0, page.height * scale)
                     x1, y1 = matrix.transform_point(*rectangle[:2])
                     x2, y2 = matrix.transform_point(*rectangle[2:])
-
                     signature = Signature.add_field(
                         weasy_form,
                         signature_field_name=element_name,
@@ -40,15 +37,3 @@ class FormFinisher:
                             'V': form_signature.reference
                         })
 
-        self.weasy_form = weasy_form
-
-    def get_buffer(self) -> bytes:
-        if not self.weasy_form:
-            raise Exception('weasy_form is not set!')
-        return self.weasy_form.write()
-
-    def write_pdf(self, target: str) -> None:
-        if not self.weasy_form:
-            raise Exception('weasy_form is not set!')
-        self.weasy_form.write(target)
-
